#!/bin/bash

# Copyright (C) 2018 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.
#============================================================================
# This script identify and installs packages required to setup new set of 
# yum repository definition files based on current yum repository configuration
#
# Usage:
#
#  ol_yum_configure.sh
#
#============================================================================

restore()
{
for file in `ls -1 /etc/yum.repos.d/*-ol6.repo`
do
  mv $file ${file}.disabled
done

   mv /etc/yum.repos.d/public-yum-ol6.repo.sav /etc/yum.repos.d/public-yum-ol6.repo
   rm -f $REPOLIST_FILE $REPOLIST_FILE_NEW $RUN_FILE
   
}

trap 'restore' 2 6 9 15

UserId=`id -u`
if [ $UserId != 0 ]; then
   echo This script need to be run as root user
   exit
fi
if [ ! -f /etc/yum.repos.d/public-yum-ol6.repo ]; then
  echo Nothing to do
  exit
fi

PACKAGE_LIST="php nodejs epel gluster oci_included ksplice spacewalk.*server spacewalk.*client mysql software openstack oraclelinux_developer patch developer oracle"

Release=`grep ^VERSION= /etc/os-release | awk -F\" '{print $2}' | awk -F. '{print $1}'`
#Release=`awk '{print $(NF)}' /etc/redhat-release | awk -F. '{print $1}'`
Arch=`uname -i`

if [ $Release = '6' -a \( $Arch = i386 -o $Arch = i686 \) ]; then
PACKAGE_LIST="spacewalk.*client mysql oraclelinux_developer patch developer"
fi

REPOLIST_FILE=/tmp/.oracle_enable_repolist
REPOLIST_FILE_NEW=/tmp/.oracle_enable_repolist_new
RUN_FILE=/etc/yum.repos.d/.ol_yum_configure

echo $PACKAGE_LIST
touch $RUN_FILE

yum-config-manager | grep ol6 | grep "^\[" | egrep -v -e "x86_64|i386" | sed -e "s|\[||" | sed -e "s|\]||" > $REPOLIST_FILE

PACKAGE_TO_INSTALL=
SPCWLK_SERVER=no
for pkg in $PACKAGE_LIST
do
   echo $pkg
   if grep -i "$pkg" $REPOLIST_FILE > /dev/null ; then
      echo found $pkg
      if [ $pkg = developer ]; then
        if  egrep -i -e "$pkg$|$pkg " $REPOLIST_FILE > /dev/null ; then
        PACKAGE_NAME=oraclelinux-developer-release-el6
        fi
      elif [ $pkg = patch ]; then
        PACKAGE_NAME=oraclelinux-patchonly-release-el6
      elif [ "$pkg" = 'spacewalk.*server' ]; then
        PACKAGE_NAME=oracle-spacewalk-server-release-el6
        SPCWLK_SERVER=yes
      elif [ "$pkg" = 'spacewalk.*client' ]; then
       PACKAGE_NAME=oracle-spacewalk-client-release-el6
      elif [ $pkg = "software" ]; then
        PACKAGE_NAME=oracle-softwarecollection-release-el6
      elif [ $pkg = "php" -o $pkg = "gluster" -o $pkg = "nodejs"  ]; then
        PACKAGE_NAME=oracle-${pkg}-release-el6
      else
        PACKAGE_NAME=${pkg}-release-el6
      fi
   PACKAGE_TO_INSTALL="$PACKAGE_TO_INSTALL $PACKAGE_NAME"
   fi
done
if [ ! -z "$PACKAGE_TO_INSTALL" ]; then
RPM_INSTALL=no
if [ $SPCWLK_SERVER = yes ]; then
 PACKAGE_TO_INSTALL=`echo $PACKAGE_TO_INSTALL | sed -e "s|spacewalk-client-release-el6||"`
fi

COMMAND="yum -y install "
for pkg in $PACKAGE_TO_INSTALL
do
  if rpm -qa | grep $pkg > /dev/null; then
     echo $pkg already installed
 else
    COMMAND="$COMMAND $pkg"
    RPM_INSTALL=yes
 fi
done

   if [ $RPM_INSTALL = yes ]; then
     echo $PACKAGE_TO_INSTALL
     echo $COMMAND
     $COMMAND
     if [ $? != 0 ]; then
       echo "Installation aborted. Exiting...."
       rm -f $RUN_FILE
       exit 
     fi

   fi
fi

yum-config-manager | grep ol6 | grep "^\[" | egrep -v -e "x86_64|i386" |  sed -e "s|\[||" | sed -e "s|\]||" > $REPOLIST_FILE
mv /etc/yum.repos.d/public-yum-ol6.repo  /etc/yum.repos.d/public-yum-ol6.repo.sav
for file in `ls -1 /etc/yum.repos.d/*-ol6.repo.disabled`
do
  mv $file `echo $file | sed -e "s|.disabled$||"`
done

yum-config-manager | grep ol6 | grep "^\[" | egrep -v -e "x86_64|i386" |  sed -e "s|\[||" | sed -e "s|\]||" > $REPOLIST_FILE_NEW

for repo in `cat $REPOLIST_FILE_NEW`
do
   if grep $repo $REPOLIST_FILE > /dev/null ; then
     echo  $repo Fine
   else
     echo Disabling $repo
     yum-config-manager --disable $repo > /dev/null
   fi
done

for file in `ls -1 /etc/yum.repos.d/*-ol6.repo.incomplete 2> /dev/null`
do
  if [ ! -f `echo $file | sed -e "s|.incomplete$||"` ]; then
    mv $file `echo $file | sed -e "s|.incomplete$||"`
  fi
done


rm -f $RUN_FILE
#rm -f $REPOLIST_FILE $REPOLIST_FILE_NEW
